@@ -12,27 +12,19 @@ insert_image_addin = function() {
 
 # use touch to update the timestamp of a file if available (not on Windows);
 # otherwise modify a file, undo it, and save it
-touch_file = function() {
+touch_file_rstudio = function() {
   ctx = rstudioapi::getSourceEditorContext()
   if (!file.exists(ctx$path)) stop('The current document has not been saved yet.')
   p = normalizePath(ctx$path); mtime = function() file.info(p)[, 'mtime']
-  m = mtime(); check_mtime = function() {
-    if (u <- !identical(m, m2 <- mtime())) message(
-      'The modification time of "', p, '" has been updated from ', m, ' to ', m2
-    )
-    u
-  }
-  if (Sys.which('touch') != '') {
-    if (system2('touch', shQuote(p)) == 0 && check_mtime()) return(TRUE)
-  }
-  id = ctx$id
-  # add a space and delete it, then (re)save the document to update its mtime
-  rstudioapi::insertText(c(1, 1), ' ', id = id)
-  rstudioapi::modifyRange(list(c(1, 1, 1, 2)), '', id)
-  rstudioapi::documentSave(id)
-  check_mtime()
+  m = mtime()
+  on.exit(if (!identical(m, m2 <- mtime())) message(
+    'The modification time of "', p, '" has been updated from ', m, ' to ', m2
+  ), add = TRUE)
+  touch_file(p)
 }
 
+touch_file = function(path, time = Sys.time()) Sys.setFileTime(path, time)
+
 # add > to the beginning of every paragraph, and two trailing spaces to every line
 quote_poem = function(x) {
   x = paste(x, collapse = '\n')
