@@ -2,5 +2,5 @@ local({
   library(methods)
   args = commandArgs(TRUE)
   if (length(args) > 1) setwd(args[2])
-  rmarkdown::render(args[1], envir = globalenv(), quiet = TRUE, encoding = 'UTF-8')
+  rmarkdown::render(args[1], envir = globalenv(), quiet = TRUE)
 })
