@@ -8,7 +8,7 @@ assert('list_rmds() ignores thing in renv / packrat folder', {
   dir.create(file.path(dir, 'renv'))
   file.create(file.path(dir, 'renv/ignore.Rmd'))
 
-  rmd = blogdown:::list_rmds(dir)
+  rmd = list_rmds(dir)
   (rmd %==% character())
 
   unlink(dir, recursive = TRUE)
